@@ -2161,7 +2161,7 @@ def grashof(g, L, nu, *, mode="heat",
         if beta_star is None or Ca_s is None or Ca_a is None:
             raise ValueError("For 'mass' mode, beta_star, Ca_s, and Ca_a must be provided.")
         beta_star, Ca_s, Ca_a = validate_inputs(beta_star, Ca_s, Ca_a)
-        delta_Ca = Ca_s - Ca_a
+        delta_Ca = np.abs(Ca_s - Ca_a)
         numerator = g * beta_star * delta_Ca * L**3
     else:
         raise ValueError("Mode must be either 'heat' or 'mass'.")
